'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.diff = void 0;
const lodash_1 = require("lodash");
const deeks_1 = require("deeks");
const doc_path_1 = require("doc-path");
function diff(objectA, objectB) {
    if (typeof objectA === 'undefined' || !(typeof objectA === 'object') || typeof objectB === 'undefined' || !(typeof objectB === 'object')) {
        throw new Error('Two valid objects must be provided.');
    }
    const aKeys = (0, deeks_1.deepKeys)(objectA);
    const bKeys = (0, deeks_1.deepKeys)(objectB);
    const combinedKeys = [...new Set([...aKeys, ...bKeys])];
    const differences = [];
    combinedKeys.forEach(docPath => {
        const objectAVal = (0, doc_path_1.evaluatePath)(objectA, docPath), objectBVal = (0, doc_path_1.evaluatePath)(objectB, docPath);
        if (!(0, lodash_1.isEqual)(objectAVal, objectBVal)) {
            differences.push({
                path: docPath,
                original: objectAVal,
                updated: objectBVal
            });
        }
    });
    return differences;
}
exports.diff = diff;
